==> ejc-probuilddiary-impl-3.0.0-20220916.100920-7-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonSafetyEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-安全活动情况（安全员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_safety")
public class PersonSafetyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="safety_id")
    private Long safetyId; // 工作类别id
    @TableField(value="safety_name")
    private String safetyName; // 工作类别名称
    @TableField(value="safety_code")
    private String safetyCode; // 工作类别编码
    @TableField(value="safety_memo")
    private String safetyMemo; // 工作描述
    
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getSafetyId() {
        return safetyId;
    }

    public void setSafetyId(Long safetyId) {
        this.safetyId = safetyId;
    }
    public String getSafetyName() {
        return safetyName;
    }

    public void setSafetyName(String safetyName) {
        this.safetyName = safetyName;
    }
    public String getSafetyCode() {
        return safetyCode;
    }

    public void setSafetyCode(String safetyCode) {
        this.safetyCode = safetyCode;
    }
    public String getSafetyMemo() {
        return safetyMemo;
    }

    public void setSafetyMemo(String safetyMemo) {
        this.safetyMemo = safetyMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220919.071841-10-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonSafetyEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-安全活动情况（安全员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_safety")
public class PersonSafetyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="safety_id")
    private Long safetyId; // 工作类别id
    @TableField(value="safety_name")
    private String safetyName; // 工作类别名称
    @TableField(value="safety_code")
    private String safetyCode; // 工作类别编码
    @TableField(value="safety_memo")
    private String safetyMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型


    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getSafetyId() {
        return safetyId;
    }

    public void setSafetyId(Long safetyId) {
        this.safetyId = safetyId;
    }
    public String getSafetyName() {
        return safetyName;
    }

    public void setSafetyName(String safetyName) {
        this.safetyName = safetyName;
    }
    public String getSafetyCode() {
        return safetyCode;
    }

    public void setSafetyCode(String safetyCode) {
        this.safetyCode = safetyCode;
    }
    public String getSafetyMemo() {
        return safetyMemo;
    }

    public void setSafetyMemo(String safetyMemo) {
        this.safetyMemo = safetyMemo;
    }
    
}
